Files
TheRock/rocm-systems/projects/hip-tests/catch/unit/executionControl/hipFuncSetSharedMemConfig.cc
T
derek.holloway 7502bf64a4
CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
Flatten subprojects into a single base monorepo
2026-09-02 16:34:47 -07:00

100 lines
2.9 KiB
C++

/*
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
*
* SPDX-License-Identifier: MIT
*/
#include "execution_control_common.hh"
#include <hip_test_common.hh>
#include <hip/hip_runtime_api.h>
/**
* @addtogroup hipFuncSetSharedMemConfig hipFuncSetSharedMemConfig
* @{
* @ingroup ExecutionTest
* `hipFuncSetSharedMemConfig(const void* func, hipSharedMemConfig config)` -
* Set shared memory configuation for a specific function.
*/
namespace {
constexpr std::array<hipSharedMemConfig, 3> kSharedMemConfigs{
hipSharedMemBankSizeDefault, hipSharedMemBankSizeFourByte, hipSharedMemBankSizeEightByte};
} // anonymous namespace
/**
* Test Description
* ------------------------
* - Sets cache config for every shared memory config enumeration.
* Test source
* ------------------------
* - unit/executionControl/hipFuncSetSharedMemConfig.cc
* Test requirements
* ------------------------
* - HIP_VERSION >= 5.2
*/
HIP_TEST_CASE(Unit_hipFuncSetSharedMemConfig_Positive_Basic) {
const auto shared_mem_config =
GENERATE(from_range(begin(kSharedMemConfigs), end(kSharedMemConfigs)));
HIP_CHECK(hipFuncSetSharedMemConfig(reinterpret_cast<void*>(kernel), shared_mem_config));
kernel<<<1, 1>>>();
HIP_CHECK(hipDeviceSynchronize());
}
/**
* Test Description
* ------------------------
* - Validates handling of invalid arguments:
* -# When pointer to the kernel function is `nullptr`
* - Expected output: return `hipErrorInvalidDeviceFunction`
* -# When shared memory config enumeration is invalid
* - Expected output: return `hipErrorInvalidValue`
* Test source
* ------------------------
* - unit/executionControl/hipFuncSetSharedMemConfig.cc
* Test requirements
* ------------------------
* - HIP_VERSION >= 5.2
*/
HIP_TEST_CASE(Unit_hipFuncSetSharedMemConfig_Negative_Parameters) {
SECTION("func == nullptr") {
HIP_CHECK_ERROR(hipFuncSetSharedMemConfig(nullptr, hipSharedMemBankSizeDefault),
hipErrorInvalidDeviceFunction);
}
SECTION("invalid shared mem config") {
HIP_CHECK_ERROR(hipFuncSetSharedMemConfig(reinterpret_cast<void*>(kernel),
static_cast<hipSharedMemConfig>(-1)),
hipErrorInvalidValue);
}
}
/**
* Test Description
* ------------------------
* - Sets shared memory config that is not supported.
* - Expected output: return `hipErrorNotSupported`
* Test source
* ------------------------
* - unit/executionControl/hipFuncSetSharedMemConfig.cc
* Test requirements
* ------------------------
* - Platform specific (AMD)
* - HIP_VERSION >= 5.2
*/
HIP_TEST_CASE(Unit_hipFuncSetSharedMemConfig_Negative_Not_Supported) {
#if HT_NVIDIA
HIP_SKIP_TEST(HipTest::SkipReason::kApiUnsupportedOnNvidia);
#endif
HIP_CHECK_ERROR(
hipFuncSetSharedMemConfig(reinterpret_cast<void*>(kernel), hipSharedMemBankSizeDefault),
hipErrorNotSupported);
}
/**
* End doxygen group ExecutionTest.
* @}
*/